@@ -9,10 +9,17 @@ import distutils.dir_util
 import zbuilder.vm
 import zbuilder.cfg
 
-from zbuilder.helpers import getHosts, getProviders, runPlaybook, fixKeys, runCmd, humanize_time
+from zbuilder.helpers import (
+    getHosts,
+    getProviders,
+    runPlaybook,
+    fixKeys,
+    runCmd,
+    humanize_time,
+)
 from zbuilder.options import pass_state, common_options
 
-from click._bashcomplete import get_completion_script
+from click.shell_completion import get_completion_class
 
 
 @click.group()
@@ -22,16 +29,16 @@ def cli():
 
 
 @cli.command()
-@click.option('--template', default='devel', help='Environment template')
+@click.option("--template", default="devel", help="Environment template")
 @common_options
 @pass_state
 def init(state, template):
     """Init an environment"""
-    if os.path.exists('group_vars') or os.path.exists('hosts'):
+    if os.path.exists("group_vars") or os.path.exists("hosts"):
         raise click.ClickException("This directory already contains relevant files")
 
     cfg = zbuilder.cfg.load(touch=True)
-    tmpl_path = dpath.util.get(cfg, '/main/templates/path')
+    tmpl_path = dpath.util.get(cfg, "/main/templates/path")
     TEMPLATE_PATH = os.path.join(os.path.expanduser(tmpl_path), template)
     if os.path.exists(TEMPLATE_PATH):
         click.echo("Initializing {} based zbuilder environment".format(template))
@@ -50,11 +57,12 @@ def build(state):
     click.echo("Building VMs")
     vmProviders = getHosts(state)
     for _, vmProvider in vmProviders.items():
-        vmProvider['cloud'].build(vmProvider['hosts'])
+        vmProvider["cloud"].build(vmProvider["hosts"])
     click.echo("Fixing ssh keys VMs")
     fixKeys(state)
-    click.echo("Running bootstrap.yml")
-    runPlaybook(state, "bootstrap.yml")
+    if os.path.exists("bootstrap.yml"):
+        click.echo("Running bootstrap.yml")
+        runPlaybook(state, "bootstrap.yml")
     end_time = time.time()
     click.echo("Time elapsed: {}".format(humanize_time(end_time - start_time)))
 
@@ -67,7 +75,7 @@ def up(state):
     click.echo("Booting VMs")
     vmProviders = getHosts(state)
     for _, vmProvider in vmProviders.items():
-        vmProvider['cloud'].up(vmProvider['hosts'])
+        vmProvider["cloud"].up(vmProvider["hosts"])
 
 
 @cli.command()
@@ -78,7 +86,7 @@ def halt(state):
     click.echo("Halting VMs")
     vmProviders = getHosts(state)
     for _, vmProvider in vmProviders.items():
-        vmProvider['cloud'].halt(vmProvider['hosts'])
+        vmProvider["cloud"].halt(vmProvider["hosts"])
 
 
 @cli.command()
@@ -90,21 +98,25 @@ def destroy(state):
     vmProviders = getHosts(state)
     for _, vmProvider in vmProviders.items():
         zbuilder_env = None
-        for h in vmProvider['hosts']:
-            if 'ZBUILDER_ENV' in vmProvider['hosts'][h]:
-                if 'prod' in vmProvider['hosts'][h]['ZBUILDER_ENV'].lower():
-                    zbuilder_env = vmProvider['hosts'][h]['ZBUILDER_ENV']
+        for h in vmProvider["hosts"]:
+            if "ZBUILDER_ENV" in vmProvider["hosts"][h]:
+                if "prod" in vmProvider["hosts"][h]["ZBUILDER_ENV"].lower():
+                    zbuilder_env = vmProvider["hosts"][h]["ZBUILDER_ENV"]
                     break
-                if 'prd' in vmProvider['hosts'][h]['ZBUILDER_ENV'].lower():
-                    zbuilder_env = vmProvider['hosts'][h]['ZBUILDER_ENV']
+                if "prd" in vmProvider["hosts"][h]["ZBUILDER_ENV"].lower():
+                    zbuilder_env = vmProvider["hosts"][h]["ZBUILDER_ENV"]
                     break
         if zbuilder_env:
-            if click.confirm("  The ZBUILDER_ENV is set to [{}] Do you want to continue?".format(zbuilder_env)):
-                vmProvider['cloud'].destroy(vmProvider['hosts'])
+            if click.confirm(
+                "  The ZBUILDER_ENV is set to [{}] Do you want to continue?".format(
+                    zbuilder_env
+                )
+            ):
+                vmProvider["cloud"].destroy(vmProvider["hosts"])
             else:
                 click.echo("    Aborting!")
         else:
-            vmProvider['cloud'].destroy(vmProvider['hosts'])
+            vmProvider["cloud"].destroy(vmProvider["hosts"])
 
 
 @cli.command()
@@ -130,7 +142,7 @@ def dns_update(state):
     click.echo("Updating DNS records")
     vmProviders = getHosts(state)
     for _, vmProvider in vmProviders.items():
-        vmProvider['cloud'].dnsupdate(vmProvider['hosts'])
+        vmProvider["cloud"].dnsupdate(vmProvider["hosts"])
 
 
 @dns.command()
@@ -141,7 +153,7 @@ def remove(state):
     click.echo("Removing DNS records")
     vmProviders = getHosts(state)
     for _, vmProvider in vmProviders.items():
-        vmProvider['cloud'].dnsremove(vmProvider['hosts'])
+        vmProvider["cloud"].dnsremove(vmProvider["hosts"])
 
 
 @cli.group()
@@ -158,7 +170,7 @@ def create(state):
     click.echo("Creating VMs snapshots")
     vmProviders = getHosts(state)
     for _, vmProvider in vmProviders.items():
-        vmProvider['cloud'].snapCreate(vmProvider['hosts'])
+        vmProvider["cloud"].snapCreate(vmProvider["hosts"])
 
 
 @snapshot.command()
@@ -169,7 +181,7 @@ def restore(state):
     click.echo("Restoring VMs snapshots")
     vmProviders = getHosts(state)
     for _, vmProvider in vmProviders.items():
-        vmProvider['cloud'].snapRestore(vmProvider['hosts'])
+        vmProvider["cloud"].snapRestore(vmProvider["hosts"])
 
 
 @snapshot.command()
@@ -180,11 +192,11 @@ def delete(state):
     click.echo("Deleting VMs snapshots")
     vmProviders = getHosts(state)
     for _, vmProvider in vmProviders.items():
-        vmProvider['cloud'].snapDelete(vmProvider['hosts'])
+        vmProvider["cloud"].snapDelete(vmProvider["hosts"])
 
 
 @cli.command()
-@click.argument('playbook')
+@click.argument("playbook")
 @common_options
 @pass_state
 def play(state, playbook):
@@ -199,19 +211,23 @@ def summary(state):
     vmProviders = getHosts(state)
     data = []
     for _, vmProvider in vmProviders.items():
-        for h, v in vmProvider['hosts'].items():
-            data.append([vmProvider['cloud'].factory, h, vmProvider['cloud'].params(v)])
-    click.echo(tabulate.tabulate(data, headers=["Provider", "Host", 'Parameters'], tablefmt="psql"))
+        for h, v in vmProvider["hosts"].items():
+            data.append([vmProvider["cloud"].factory, h, vmProvider["cloud"].params(v)])
+    click.echo(
+        tabulate.tabulate(
+            data, headers=["Provider", "Host", "Parameters"], tablefmt="psql"
+        )
+    )
 
 
 @cli.command()
 @pass_state
 def providers(state):
     """Display providers info"""
-    click.echo('Checking providers state...')
+    click.echo("Checking providers state...")
     cfg = zbuilder.cfg.load(touch=True)
     data = getProviders(cfg, state)
-    headers = ['Name', 'Type', 'Check']
+    headers = ["Name", "Type", "Check"]
     click.echo(tabulate.tabulate(data, headers=headers))
 
 
@@ -236,16 +252,16 @@ def edit():
 
 
 @config.command()
-@click.argument('args', nargs=2)
+@click.argument("args", nargs=2)
 @pass_state
 def main(state, args):
     """Configure main parameters"""
     cfg = zbuilder.cfg.load(touch=True)
 
-    base_path = args[0].replace('.', '/')
-    sub_path, value = args[1].split('=')
-    if ',' in value:
-        value = value.split(',')
+    base_path = args[0].replace(".", "/")
+    sub_path, value = args[1].split("=")
+    if "," in value:
+        value = value.split(",")
     cfg_path = "main/{}/{}".format(base_path, sub_path)
 
     click.echo("Setting config /{} to {}".format(cfg_path, value))
@@ -254,19 +270,19 @@ def main(state, args):
 
 
 @config.command()
-@click.argument('args', nargs=2)
+@click.argument("args", nargs=2)
 @pass_state
 def provider(state, args):
     """Configure a provider"""
     cfg = zbuilder.cfg.load(touch=True)
 
-    base_path = args[0].replace('.', '/')
-    sub_path, value = args[1].split('=', 1)
-    if ',' in value:
-        value = value.split(',')
-    if value in ['True', 'true']:
+    base_path = args[0].replace(".", "/")
+    sub_path, value = args[1].split("=", 1)
+    if "," in value:
+        value = value.split(",")
+    if value in ["True", "true"]:
         value = True
-    if value in ['False', 'false']:
+    if value in ["False", "false"]:
         value = False
     cfg_path = "providers/{}/{}".format(base_path, sub_path)
 
@@ -276,26 +292,32 @@ def provider(state, args):
 
 
 @config.command()
-@click.option('--yes', is_flag=True)
+@click.option("--yes", is_flag=True)
 @pass_state
 def update(state, yes):
     """Update configuration components"""
     if not yes:
-        click.confirm('Do you want to update?', abort=True)
+        click.confirm("Do you want to update?", abort=True)
 
     cfg = zbuilder.cfg.load(touch=True)
     try:
-        tmpl_repo = dpath.util.get(cfg, '/main/templates/repo')
-        tmpl_path = dpath.util.get(cfg, '/main/templates/path')
+        tmpl_repo = dpath.util.get(cfg, "/main/templates/repo")
+        tmpl_path = dpath.util.get(cfg, "/main/templates/path")
         if tmpl_repo and tmpl_path:
             click.echo(" * Updating templates")
-            runCmd("git -C {path} pull || git clone {repo} {path}".format(repo=tmpl_repo, path=tmpl_path))
+            runCmd(
+                "git -C {path} pull || git clone {repo} {path}".format(
+                    repo=tmpl_repo, path=tmpl_path
+                )
+            )
     except KeyError:
         pass
 
 
 @cli.command()
-@click.argument('shell', default='bash')
+@click.argument("shell", default="bash")
 def completion(shell):
     """Autocomplete for bash"""
-    click.echo(get_completion_script('zbuilder', '_ZBUILDER_COMPLETE', shell))
+    comp_cls = get_completion_class(shell)
+    comp = comp_cls(cli, {}, "zbuilder", "_ZBUILDER_COMPLETE")
+    click.echo(comp.source())
