@@ -12,14 +12,18 @@ def waitDNS(hostname, ip):
     click.echo("  - Waiting for host [{}] DNS to sync".format(hostname))
     while not synced:
         try:
-            answers = dns.resolver.query(hostname, 'A')
+            answers = dns.resolver.query(hostname, "A")
             ttl = answers.rrset.ttl
             rip = answers[0].address
             if rip == ip:
                 click.echo("  - Host [{}] is synced with ip [{}]".format(hostname, rip))
                 synced = True
             else:
-                click.echo("  - Host [{}] is not synced with ip [{} != {}], sleeping for [{}]".format(hostname, ip, rip, ttl+1))
+                click.echo(
+                    "  - Host [{}] is not synced with ip [{} != {}], sleeping for [{}]".format(
+                        hostname, ip, rip, ttl + 1
+                    )
+                )
                 time.sleep(ttl + 1)
         except dns.resolver.NXDOMAIN:
             click.echo("    Sleeping 20s due to NXDOMAIN")
@@ -31,8 +35,8 @@ def waitDNS(hostname, ip):
 
 def getProvider(zone, cfg):
     for p, v in cfg.items():
-        if 'dns' in v and 'zones' in v['dns'] and zone in v['dns']['zones']:
-            return dnsProvider(cfg[p]['type'], cfg[p])
+        if "dns" in v and "zones" in v["dns"] and zone == v["dns"]["zones"]:
+            return dnsProvider(cfg[p]["type"], cfg[p])
     return None
 
 
@@ -41,16 +45,16 @@ def dnsUpdate(ips):
     waitList = {}
     provider = None
     for hostname, ip in ips.items():
-        zone = hostname.partition('.')[2]
-        host = hostname.partition('.')[0]
-        provider = getProvider(zone, cfg['providers'])
+        zone = hostname.partition(".")[2]
+        host = hostname.partition(".")[0]
+        provider = getProvider(zone, cfg["providers"])
         if provider:
             provider.update(host, zone, ip)
             waitList[hostname] = ip
         else:
             click.echo("No DNS provider found for zone [{}]".format(zone))
 
-    if provider and provider.factory != 'ansible':
+    if provider and provider.factory != "ansible":
         for hostname, ip in waitList.items():
             waitDNS(hostname, ip)
 
@@ -58,9 +62,9 @@ def dnsUpdate(ips):
 def dnsRemove(hosts):
     cfg = zbuilder.cfg.load()
     for hostname in hosts:
-        zone = hostname.partition('.')[2]
-        host = hostname.partition('.')[0]
-        provider = getProvider(zone, cfg['providers'])
+        zone = hostname.partition(".")[2]
+        host = hostname.partition(".")[0]
+        provider = getProvider(zone, cfg["providers"])
         if provider:
             provider.remove(host, zone)
         else:
@@ -70,7 +74,9 @@ def dnsRemove(hosts):
 class dnsProvider(object):
     def __init__(self, factory, cfg=None):
         self.factory = factory
-        dnsProviderClass = getattr(importlib.import_module("zbuilder.dns.%s" % factory), "dnsProvider")
+        dnsProviderClass = getattr(
+            importlib.import_module("zbuilder.dns.%s" % factory), "dnsProvider"
+        )
         self.provider = dnsProviderClass(cfg)
 
     @trywrap
