@@ -6,7 +6,7 @@ class dnsProvider(object):
     def __init__(self, cfg):
         if cfg:
             self.cfg = cfg
-            self.apikey = self.cfg['apikey']
+            self.apikey = self.cfg["apikey"]
             self.manager = digitalocean.Manager(token=self.apikey)
 
     def getRecord(self, host, zone, ip=None):
@@ -19,7 +19,9 @@ class dnsProvider(object):
                 continue
 
         if ip and not retValue:
-            retValue = digitalocean.Record(token=self.apikey, domain_name=zone, name=host, type='A', data=ip)
+            retValue = digitalocean.Record(
+                token=self.apikey, domain_name=zone, name=host, type="A", data=ip
+            )
 
         return retValue
 
@@ -27,10 +29,14 @@ class dnsProvider(object):
         fqdn = "{}.{}".format(host, zone)
         record = self.getRecord(host, zone, ip)
         if not record.id:
-            click.echo("  - Creating record [{}] with ip [{}]".format(fqdn, record.data))
+            click.echo(
+                "  - Creating record [{}] with ip [{}]".format(fqdn, record.data)
+            )
             record.create()
         else:
-            click.echo("  - Updating record [{}] with ip [{}]".format(fqdn, record.data))
+            click.echo(
+                "  - Updating record [{}] with ip [{}]".format(fqdn, record.data)
+            )
             record.save()
 
     def remove(self, host, zone):
