@@ -7,14 +7,14 @@ from zbuilder.wrappers import trywrap
 
 def getProvider(subnet, cfg):
     for p, v in cfg.items():
-        if 'ipam' in v and 'subnets' in v['ipam'] and subnet in v['ipam']['subnets']:
-            return ipamProvider(cfg[p]['type'], cfg[p])
+        if "ipam" in v and "subnets" in v["ipam"] and subnet in v["ipam"]["subnets"]:
+            return ipamProvider(cfg[p]["type"], cfg[p])
     return None
 
 
 def ipamReserve(hostname, subnet):
     cfg = zbuilder.cfg.load()
-    provider = getProvider(subnet, cfg['providers'])
+    provider = getProvider(subnet, cfg["providers"])
     if provider:
         return provider.reserve(hostname, subnet)
     else:
@@ -23,7 +23,7 @@ def ipamReserve(hostname, subnet):
 
 def ipamLocate(hostname, subnet):
     cfg = zbuilder.cfg.load()
-    provider = getProvider(subnet, cfg['providers'])
+    provider = getProvider(subnet, cfg["providers"])
     if provider:
         return provider.locate(hostname, subnet)
     else:
@@ -32,7 +32,7 @@ def ipamLocate(hostname, subnet):
 
 def ipamRelease(hostname, ip, subnet):
     cfg = zbuilder.cfg.load()
-    provider = getProvider(subnet, cfg['providers'])
+    provider = getProvider(subnet, cfg["providers"])
     if provider:
         provider.release(hostname, ip, subnet)
     else:
@@ -43,7 +43,9 @@ class ipamProvider(object):
     def __init__(self, factory, cfg=None):
         self.factory = factory
         self.cfg = cfg
-        ipamProviderClass = getattr(importlib.import_module("zbuilder.ipam.%s" % factory), "ipamProvider")
+        ipamProviderClass = getattr(
+            importlib.import_module("zbuilder.ipam.%s" % factory), "ipamProvider"
+        )
         self.provider = ipamProviderClass(cfg)
 
     @trywrap
