@@ -12,28 +12,28 @@ class vmProvider(object):
     def __init__(self, cfg):
         if cfg:
             self.cfg = cfg
-            self.apikey = self.cfg['apikey']
+            self.apikey = self.cfg["apikey"]
             self.manager = digitalocean.Manager(token=self.apikey)
 
     def getDroplets(self, hosts):
         retValue = {}
         droplets = self.manager.get_all_droplets()
         for h, v in hosts.items():
-            if hosts[h]['enabled']:
+            if hosts[h]["enabled"]:
                 for droplet in droplets:
                     if droplet.name == h:
                         retValue[droplet.name] = droplet
                 if h not in retValue:
                     for curkey in self.manager.get_all_sshkeys():
-                        if curkey.name == v['sshkey']:
+                        if curkey.name == v["sshkey"]:
                             sshkey = curkey
                             continue
                     droplet = digitalocean.Droplet(
                         token=self.apikey,
                         name=h,
-                        region=v['region'],
-                        image=v['image'],
-                        size_slug=v['size_slug'],
+                        region=v["region"],
+                        image=v["image"],
+                        size_slug=v["size_slug"],
                         ssh_keys=[sshkey],
                         monitoring=True,
                         backups=False,
@@ -59,15 +59,15 @@ class vmProvider(object):
                 click.echo("  - Creating host: {} ".format(d.name))
                 d.create()
                 ips[d.name] = None
-            elif d.status == 'off':
+            elif d.status == "off":
                 click.echo("  - Booting host: {} ".format(d.name))
                 d.power_on()
-            elif d.status == 'active':
+            elif d.status == "active":
                 click.echo("  - Already up host: {} ".format(d.name))
             else:
                 click.echo("  - Status of host: {} is {}".format(d.name, d.status))
 
-        self.waitStatus(hosts, 'active')
+        self.waitStatus(hosts, "active")
         for k, d in self.getDroplets(hosts).items():
             if d.ip_address:
                 ips[d.name] = d.ip_address
@@ -78,23 +78,23 @@ class vmProvider(object):
         for k, d in self.getDroplets(hosts).items():
             if d.status is None:
                 click.echo("  - No such host: {} ".format(d.name))
-            elif d.status == 'off':
+            elif d.status == "off":
                 click.echo("  - Booting host: {} ".format(d.name))
                 d.power_on()
-            elif d.status == 'active':
+            elif d.status == "active":
                 click.echo("  - Already up host: {} ".format(d.name))
             else:
                 click.echo("  - Status of host: {} is {}".format(d.name, d.status))
 
     def halt(self, hosts):
         for k, d in self.getDroplets(hosts).items():
-            if d.status == 'active':
+            if d.status == "active":
                 click.echo("  - Halting host: {} ".format(d.name))
                 d.shutdown()
             else:
                 click.echo("  - Status of host: {} is {}".format(d.name, d.status))
 
-        self.waitStatus(hosts, 'off')
+        self.waitStatus(hosts, "off")
 
     def destroy(self, hosts):
         updateHosts = {}
@@ -118,7 +118,7 @@ class vmProvider(object):
     def dnsremove(self, hosts):
         ips = {}
         for h in hosts:
-            if hosts[h]['enabled']:
+            if hosts[h]["enabled"]:
                 ips[h] = None
         dnsRemove(hosts)
 
@@ -142,10 +142,10 @@ class vmProvider(object):
 
         click.echo("  Halting")
         self.halt(hosts)
-        self.waitStatus(hosts, 'off')
+        self.waitStatus(hosts, "off")
         click.echo("  Restoring")
         for k, d in self.getDroplets(hosts).items():
-            if d.status == 'off':
+            if d.status == "off":
                 snapshot_name = "zbuilder-{}".format(d.name)
                 if snapshot_name in snaps.keys():
                     click.echo("  - Restoring from image: {} ".format(snapshot_name))
@@ -154,7 +154,7 @@ class vmProvider(object):
                     click.echo("  - No such snapshot: {}".format(snapshot_name))
         click.echo("  Booting up")
         self.up(hosts)
-        self.waitStatus(hosts, 'active')
+        self.waitStatus(hosts, "active")
 
     def snapDelete(self, hosts):
         snapshots = self.manager.get_droplet_snapshots()
@@ -162,7 +162,7 @@ class vmProvider(object):
         for s in snapshots:
             snaps[s.name] = s
         for h in hosts:
-            if hosts[h]['enabled']:
+            if hosts[h]["enabled"]:
                 snapshot_name = "zbuilder-{}".format(h)
                 if snapshot_name in snaps.keys():
                     click.echo("  - Deleting snapshot: {}".format(snapshot_name))
@@ -171,7 +171,10 @@ class vmProvider(object):
                     click.echo("  - No such snapshot: {}".format(snapshot_name))
 
     def config(self):
-        return "apikey: {}...".format(self.cfg['apikey'][0:10])
+        return "apikey: {}...".format(self.cfg["apikey"][0:10])
 
     def status(self):
         return "PASS"
+
+    def params(self, params):
+        return {k: params.get(k, None) for k in ["size_slug", "region", "image"]}
